#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-GEtzs9L951QIGY3dhKzl2A
key:                  stack-2.9.3.1-GEtzs9L951QIGY3dhKzl2A
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  194e927b09866181830b3b25812327e7
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-GEtzs9L951QIGY3dhKzl2A
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-I4TBg1DJhLsFbcwgkuafNJ
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-EWnhDZJXy1I5W5pwBR2UDi array-0.5.6.0
    async-2.2.6-59NIAOAPAyhA1W6qbURVB1
    attoparsec-0.14.4-XKrSjVngnD4c93iEpE5SP base-4.18.2.1
    base64-bytestring-1.2.1.0-HTSPucLWQY58n8fXtuig9 bytestring-0.11.5.3
    casa-client-0.0.3-6fjEIlh07NOwMa0TdAMI6
    casa-types-0.0.3-28qWW9CYtsb8Qe0tqFNJbM
    colour-2.3.7-Ixzlu8Z2rqj57CGhj95tZ3
    conduit-1.3.6.1-EcgUgvtEMLyH8F5dS2Qay5
    conduit-extra-1.3.8-Pkl5t82V3lFiXu05t8a32 containers-0.6.7
    crypton-1.0.4-7rGtxTEpZ4u1PsW0CXdnJs
    crypton-conduit-0.2.3-JuXEshD5MoiLkj3L7c2i4n deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-D7xOqdBl5Y0CRCTPxKeT4r
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-Gspjwzx4LSD39QFV46vWS9 filepath-1.4.300.1
    fsnotify-0.4.4.0-KGbgpyaRchX7mTKaOISr4f
    generic-deriving-1.14.7-i1qhtwZsnwL9L6nK0vbzi
    hackage-security-0.6.3.2-9uNoOnsXGfI5sbr0Oawb3E
    hashable-1.4.7.0-LnVJu1JSZWR8SeekGz9T3N
    hi-file-parser-0.1.8.0-BprI2xfsheCIiiGynIrO3o
    hpack-0.38.0-1xIY1d7Hl1PKmn0GBN2yLW hpc-0.6.2.0
    http-client-0.7.19-D9XDbMj7HQLAGyouPpExP5
    http-client-tls-0.3.6.4-Eim5k3MjTxi7mUqUwtCUuU
    http-conduit-2.3.9.1-4xpeFSGMYU5Jef4BWByQnK
    http-download-0.2.1.0-6WIXhM4bD8PFLdfesmJSD3
    http-types-0.12.4-J4f9RYTa0ze5zkpv7SJ8lm
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-F5y4rarZYra8uwlKyBnvfZ mtl-2.3.1
    mustache-2.4.3.1-DoknlDlU99RFCLyAZhZ7Is
    neat-interpolation-0.5.1.4-JIiEn1HbYYyKBBMzjvNSYj
    network-uri-2.6.4.2-CG8j03sAL8xAn9DHaXlCLv
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-F2USUEHNufd3B1Lo6sWmKk
    pantry-0.8.3-Ipy9S4M15Cp8Q6pKj4Brci
    path-0.9.6-7DlPI4eV5bF2D75WxJeaik
    path-io-1.8.2-Dr0It13TwFq2tugZgQ9i2M
    persistent-2.14.5.2-C6G6kwanc0M1lQZcg04mvO
    persistent-sqlite-2.13.2.0-JQRwGITBSpY8McpWRMUQKG pretty-1.1.3.6
    primitive-0.9.1.0-CQgznoWdG1cWDpxantBgk process-1.6.19.0
    project-template-0.2.1.0-JyUk4RFISW5JC4nNWvPOdY
    random-1.2.1.3-LwaPdrRXsBLJH2A1U2p1p
    retry-0.9.3.1-9kv3xUTwHsKHolPZBhJOGN
    rio-0.1.24.0-FiNY3wrLNKA2TEFZcUwxm1
    rio-prettyprint-0.1.8.0-H1Z8v9ucdIj9oIqCF8xJkp
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    streaming-commons-0.2.3.1-3Xesx0fbBDO4oGhGaRU7jz
    tar-0.5.1.1-IJAjAM7qgxpFPDj1wF26Ge template-haskell-2.20.0.0
    temporary-1.3-2gC7gXJ3mT3YNg5WXhcSt text-2.0.2
    text-metrics-0.3.3-8EhWZ2VuUlbIiYDUqXogex
    th-reify-many-0.1.10-AMdvWj5R0b3AKUNtZRTsge time-1.12.2
    tls-2.0.6-L1CXpmp4taTKKTqOC9HsCU transformers-0.6.1.0
    typed-process-0.2.13.0-73UILXLuYzQ9eZGdwL0BYm
    unicode-transforms-0.4.0.1-BgqTX2yvMUJH5LYRlQeRPr unix-2.8.4.0
    unix-compat-0.7.4.1-HK3thdsDfAWHXS2uR0zDUL
    unliftio-0.2.25.1-2kLBdqoZ53hQro8XfzgjZ
    unordered-containers-0.2.20.1-9MqMq77Kwyw3AYghIevUCW
    vector-0.13.2.0-KxN9ggrWD4mCYNpXRxsIZo
    yaml-0.11.11.2-LmJ3lQubKx2LZPMJyshbOQ
    zip-archive-0.4.3.2-IbN3XUsKsBH9cnGjOnWklQ
    zlib-0.7.1.0-9Et02hV6Q1320HoMtTepaj

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

